
/*****************************Documentation Start***********************************

  NAME: syntaxchk.h  - Header file for syntaxchk.c and user code that invokes
                       syntaxchk.c


  DESCRIPTION:

  This file contains definitions used by syntaxchk.c, and callers of syntaxchk.c



  HISTORY:

  Date        Who Description
  ----------- --- -----------------------------------------------------------------
  2004-Jun-01 RXT Created
  2005-Jul-07 RXT Add defines for specific return codes
                  Define token type GOTORULE
                  Define SYSTEM_TOKENS to indicate start of internal token values
  2005-Jul-08 RXT Define token type STARTRULE, used to occupy table entry 0, and
                  return code indicating absence of this token type in table
  2005-Dec-14 RXT Increased GoTo defs to 1000; removed leading zero for single-digit
                  numbers, e.g. GoTo1 (vs. GoTo01); added #define MAX-RULES 1000

******************************Documentation End************************************/

#define SYNTAX_ERROR         1
#define SYNTAX_PARM_IS_NULL  2
#define SYNTAX_NEXTRULE_ZERO 3
#define SYNTAX_NO_STARTRULE  4

#define TokIsData          100
#define TokIsNum           101
#define TokIsEOS           255
#define TokIsBlank           0
#define TokIsComma           1
#define TokIsEqual           2
#define TokIsLeftParen       3
#define TokIsRightParen      4
#define TokIsLessThan        5
#define TokIsGreaterThan     6
#define TokIsLeftBrace       7
#define TokIsRightBrace      8
#define TokIsDash            9
#define TokIsUnderBar       10
#define TokIsAnd            11
#define TokIsPound          12
#define TokIsAt             13
#define TokIsPlus           14
#define TokIsSlash          15
#define TokIsPercent        16
#define TokIsAsterisk       17
#define TokIsSemiColon      18
#define TokIsColon          19
#define TokIsSingleQuote    20
#define TokIsDoubleQuote    21
#define TokIsTilde          22
#define TokIsBar            23
#define TokIsQuestion       24
#define TokIsPeriod         25
#define TokIsExclamation    26
#define TokIsBackSlash      27
#define TokIsDollar         28
#define TokIsReverseQuote   29
#define TokIsLeftBracket    30
#define TokIsRightBracket   31

#define SYSTEM_TOKENS      999   /* Used to indicate start of internal tokens               */
#define DUMMYRULE        39321   /* Used to reserve space for a rule set for future changes */
#define STARTRULE        43690   /* Used to occupy the first table entry                    */
#define GOTORULE         48059   /* Used to branch to another rule                          */
#define CONTRULE         52428   /* Indicates a statement continuation delimiter encountered*/
#define SYNTAXERR        56797   /* Indicates a syntax error found                          */
#define LASTRULE         61166   /* Marks the successful end of a rule "path"               */

/* "Next Rule" offsets
   These values reflect the location of the next "rule" to be applied during syntax checking.  
   In effect, the values reflect the indexed location of the struct entry that contains the 
   next "rule". Since these are hard-coded offsets, care should be taken when changes are made. 

   NOTE: Use DUMMYRULE to reserve space for future changes  */

#define MAX_RULES       1000     /* Maximum number of syntax rules allowed                  */
 
#define GoTo0              0
#define GoTo1              1
#define GoTo2              2
#define GoTo3              3
#define GoTo4              4
#define GoTo5              5
#define GoTo6              6
#define GoTo7              7
#define GoTo8              8
#define GoTo9              9
#define GoTo10            10
#define GoTo11            11
#define GoTo12            12
#define GoTo13            13
#define GoTo14            14
#define GoTo15            15
#define GoTo16            16
#define GoTo17            17
#define GoTo18            18
#define GoTo19            19
#define GoTo20            20
#define GoTo21            21
#define GoTo22            22
#define GoTo23            23
#define GoTo24            24
#define GoTo25            25
#define GoTo26            26
#define GoTo27            27
#define GoTo28            28
#define GoTo29            29
#define GoTo30            30
#define GoTo31            31
#define GoTo32            32
#define GoTo33            33
#define GoTo34            34
#define GoTo35            35
#define GoTo36            36
#define GoTo37            37
#define GoTo38            38
#define GoTo39            39
#define GoTo40            40
#define GoTo41            41
#define GoTo42            42
#define GoTo43            43
#define GoTo44            44
#define GoTo45            45
#define GoTo46            46
#define GoTo47            47
#define GoTo48            48
#define GoTo49            49
#define GoTo50            50
#define GoTo51            51
#define GoTo52            52
#define GoTo53            53
#define GoTo54            54
#define GoTo55            55
#define GoTo56            56
#define GoTo57            57
#define GoTo58            58
#define GoTo59            59
#define GoTo60            60
#define GoTo61            61
#define GoTo62            62
#define GoTo63            63
#define GoTo64            64
#define GoTo65            65
#define GoTo66            66
#define GoTo67            67
#define GoTo68            68
#define GoTo69            69
#define GoTo70            70
#define GoTo71            71
#define GoTo72            72
#define GoTo73            73
#define GoTo74            74
#define GoTo75            75
#define GoTo76            76
#define GoTo77            77
#define GoTo78            78
#define GoTo79            79
#define GoTo80            80
#define GoTo81            81
#define GoTo82            82
#define GoTo83            83
#define GoTo84            84
#define GoTo85            85
#define GoTo86            86
#define GoTo87            87
#define GoTo88            88
#define GoTo89            89
#define GoTo90            90
#define GoTo91            91
#define GoTo92            92
#define GoTo93            93
#define GoTo94            94
#define GoTo95            95
#define GoTo96            96
#define GoTo97            97
#define GoTo98            98
#define GoTo99            99
#define GoTo100          100
#define GoTo101          101
#define GoTo102          102
#define GoTo103          103
#define GoTo104          104
#define GoTo105          105
#define GoTo106          106
#define GoTo107          107
#define GoTo108          108
#define GoTo109          109
#define GoTo110          110
#define GoTo111          111
#define GoTo112          112
#define GoTo113          113
#define GoTo114          114
#define GoTo115          115
#define GoTo116          116
#define GoTo117          117
#define GoTo118          118
#define GoTo119          119
#define GoTo120          120
#define GoTo121          121
#define GoTo122          122
#define GoTo123          123
#define GoTo124          124
#define GoTo125          125
#define GoTo126          126
#define GoTo127          127
#define GoTo128          128
#define GoTo129          129
#define GoTo130          130
#define GoTo131          131
#define GoTo132          132
#define GoTo133          133
#define GoTo134          134
#define GoTo135          135
#define GoTo136          136
#define GoTo137          137
#define GoTo138          138
#define GoTo139          139
#define GoTo140          140
#define GoTo141          141
#define GoTo142          142
#define GoTo143          143
#define GoTo144          144
#define GoTo145          145
#define GoTo146          146
#define GoTo147          147
#define GoTo148          148
#define GoTo149          149
#define GoTo150          150
#define GoTo151          151
#define GoTo152          152
#define GoTo153          153
#define GoTo154          154
#define GoTo155          155
#define GoTo156          156
#define GoTo157          157
#define GoTo158          158
#define GoTo159          159
#define GoTo160          160
#define GoTo161          161
#define GoTo162          162
#define GoTo163          163
#define GoTo164          164
#define GoTo165          165
#define GoTo166          166
#define GoTo167          167
#define GoTo168          168
#define GoTo169          169
#define GoTo170          170
#define GoTo171          171
#define GoTo172          172
#define GoTo173          173
#define GoTo174          174
#define GoTo175          175
#define GoTo176          176
#define GoTo177          177
#define GoTo178          178
#define GoTo179          179
#define GoTo180          180
#define GoTo181          181
#define GoTo182          182
#define GoTo183          183
#define GoTo184          184
#define GoTo185          185
#define GoTo186          186
#define GoTo187          187
#define GoTo188          188
#define GoTo189          189
#define GoTo190          190
#define GoTo191          191
#define GoTo192          192
#define GoTo193          193
#define GoTo194          194
#define GoTo195          195
#define GoTo196          196
#define GoTo197          197
#define GoTo198          198
#define GoTo199          199
#define GoTo200          200
#define GoTo201          201
#define GoTo202          202
#define GoTo203          203
#define GoTo204          204
#define GoTo205          205
#define GoTo206          206
#define GoTo207          207
#define GoTo208          208
#define GoTo209          209
#define GoTo210          210
#define GoTo211          211
#define GoTo212          212
#define GoTo213          213
#define GoTo214          214
#define GoTo215          215
#define GoTo216          216
#define GoTo217          217
#define GoTo218          218
#define GoTo219          219
#define GoTo220          220
#define GoTo221          221
#define GoTo222          222
#define GoTo223          223
#define GoTo224          224
#define GoTo225          225
#define GoTo226          226
#define GoTo227          227
#define GoTo228          228
#define GoTo229          229
#define GoTo230          230
#define GoTo231          231
#define GoTo232          232
#define GoTo233          233
#define GoTo234          234
#define GoTo235          235
#define GoTo236          236
#define GoTo237          237
#define GoTo238          238
#define GoTo239          239
#define GoTo240          240
#define GoTo241          241
#define GoTo242          242
#define GoTo243          243
#define GoTo244          244
#define GoTo245          245
#define GoTo246          246
#define GoTo247          247
#define GoTo248          248
#define GoTo249          249
#define GoTo250          250
#define GoTo251          251
#define GoTo252          252
#define GoTo253          253
#define GoTo254          254
#define GoTo255          255
#define GoTo256          256
#define GoTo257          257
#define GoTo258          258
#define GoTo259          259
#define GoTo260          260
#define GoTo261          261
#define GoTo262          262
#define GoTo263          263
#define GoTo264          264
#define GoTo265          265
#define GoTo266          266
#define GoTo267          267
#define GoTo268          268
#define GoTo269          269
#define GoTo270          270
#define GoTo271          271
#define GoTo272          272
#define GoTo273          273
#define GoTo274          274
#define GoTo275          275
#define GoTo276          276
#define GoTo277          277
#define GoTo278          278
#define GoTo279          279
#define GoTo280          280
#define GoTo281          281
#define GoTo282          282
#define GoTo283          283
#define GoTo284          284
#define GoTo285          285
#define GoTo286          286
#define GoTo287          287
#define GoTo288          288
#define GoTo289          289
#define GoTo290          290
#define GoTo291          291
#define GoTo292          292
#define GoTo293          293
#define GoTo294          294
#define GoTo295          295
#define GoTo296          296
#define GoTo297          297
#define GoTo298          298
#define GoTo299          299
#define GoTo300          300
#define GoTo301          301
#define GoTo302          302
#define GoTo303          303
#define GoTo304          304
#define GoTo305          305
#define GoTo306          306
#define GoTo307          307
#define GoTo308          308
#define GoTo309          309
#define GoTo310          310
#define GoTo311          311
#define GoTo312          312
#define GoTo313          313
#define GoTo314          314
#define GoTo315          315
#define GoTo316          316
#define GoTo317          317
#define GoTo318          318
#define GoTo319          319
#define GoTo320          320
#define GoTo321          321
#define GoTo322          322
#define GoTo323          323
#define GoTo324          324
#define GoTo325          325
#define GoTo326          326
#define GoTo327          327
#define GoTo328          328
#define GoTo329          329
#define GoTo330          330
#define GoTo331          331
#define GoTo332          332
#define GoTo333          333
#define GoTo334          334
#define GoTo335          335
#define GoTo336          336
#define GoTo337          337
#define GoTo338          338
#define GoTo339          339
#define GoTo340          340
#define GoTo341          341
#define GoTo342          342
#define GoTo343          343
#define GoTo344          344
#define GoTo345          345
#define GoTo346          346
#define GoTo347          347
#define GoTo348          348
#define GoTo349          349
#define GoTo350          350
#define GoTo351          351
#define GoTo352          352
#define GoTo353          353
#define GoTo354          354
#define GoTo355          355
#define GoTo356          356
#define GoTo357          357
#define GoTo358          358
#define GoTo359          359
#define GoTo360          360
#define GoTo361          361
#define GoTo362          362
#define GoTo363          363
#define GoTo364          364
#define GoTo365          365
#define GoTo366          366
#define GoTo367          367
#define GoTo368          368
#define GoTo369          369
#define GoTo370          370
#define GoTo371          371
#define GoTo372          372
#define GoTo373          373
#define GoTo374          374
#define GoTo375          375
#define GoTo376          376
#define GoTo377          377
#define GoTo378          378
#define GoTo379          379
#define GoTo380          380
#define GoTo381          381
#define GoTo382          382
#define GoTo383          383
#define GoTo384          384
#define GoTo385          385
#define GoTo386          386
#define GoTo387          387
#define GoTo388          388
#define GoTo389          389
#define GoTo390          390
#define GoTo391          391
#define GoTo392          392
#define GoTo393          393
#define GoTo394          394
#define GoTo395          395
#define GoTo396          396
#define GoTo397          397
#define GoTo398          398
#define GoTo399          399
#define GoTo400          400
#define GoTo401          401
#define GoTo402          402
#define GoTo403          403
#define GoTo404          404
#define GoTo405          405
#define GoTo406          406
#define GoTo407          407
#define GoTo408          408
#define GoTo409          409
#define GoTo410          410
#define GoTo411          411
#define GoTo412          412
#define GoTo413          413
#define GoTo414          414
#define GoTo415          415
#define GoTo416          416
#define GoTo417          417
#define GoTo418          418
#define GoTo419          419
#define GoTo420          420
#define GoTo421          421
#define GoTo422          422
#define GoTo423          423
#define GoTo424          424
#define GoTo425          425
#define GoTo426          426
#define GoTo427          427
#define GoTo428          428
#define GoTo429          429
#define GoTo430          430
#define GoTo431          431
#define GoTo432          432
#define GoTo433          433
#define GoTo434          434
#define GoTo435          435
#define GoTo436          436
#define GoTo437          437
#define GoTo438          438
#define GoTo439          439
#define GoTo440          440
#define GoTo441          441
#define GoTo442          442
#define GoTo443          443
#define GoTo444          444
#define GoTo445          445
#define GoTo446          446
#define GoTo447          447
#define GoTo448          448
#define GoTo449          449
#define GoTo450          450
#define GoTo451          451
#define GoTo452          452
#define GoTo453          453
#define GoTo454          454
#define GoTo455          455
#define GoTo456          456
#define GoTo457          457
#define GoTo458          458
#define GoTo459          459
#define GoTo460          460
#define GoTo461          461
#define GoTo462          462
#define GoTo463          463
#define GoTo464          464
#define GoTo465          465
#define GoTo466          466
#define GoTo467          467
#define GoTo468          468
#define GoTo469          469
#define GoTo470          470
#define GoTo471          471
#define GoTo472          472
#define GoTo473          473
#define GoTo474          474
#define GoTo475          475
#define GoTo476          476
#define GoTo477          477
#define GoTo478          478
#define GoTo479          479
#define GoTo480          480
#define GoTo481          481
#define GoTo482          482
#define GoTo483          483
#define GoTo484          484
#define GoTo485          485
#define GoTo486          486
#define GoTo487          487
#define GoTo488          488
#define GoTo489          489
#define GoTo490          490
#define GoTo491          491
#define GoTo492          492
#define GoTo493          493
#define GoTo494          494
#define GoTo495          495
#define GoTo496          496
#define GoTo497          497
#define GoTo498          498
#define GoTo499          499
#define GoTo500          500
#define GoTo501          501
#define GoTo502          502
#define GoTo503          503
#define GoTo504          504
#define GoTo505          505
#define GoTo506          506
#define GoTo507          507
#define GoTo508          508
#define GoTo509          509
#define GoTo510          510
#define GoTo511          511
#define GoTo512          512
#define GoTo513          513
#define GoTo514          514
#define GoTo515          515
#define GoTo516          516
#define GoTo517          517
#define GoTo518          518
#define GoTo519          519
#define GoTo520          520
#define GoTo521          521
#define GoTo522          522
#define GoTo523          523
#define GoTo524          524
#define GoTo525          525
#define GoTo526          526
#define GoTo527          527
#define GoTo528          528
#define GoTo529          529
#define GoTo530          530
#define GoTo531          531
#define GoTo532          532
#define GoTo533          533
#define GoTo534          534
#define GoTo535          535
#define GoTo536          536
#define GoTo537          537
#define GoTo538          538
#define GoTo539          539
#define GoTo540          540
#define GoTo541          541
#define GoTo542          542
#define GoTo543          543
#define GoTo544          544
#define GoTo545          545
#define GoTo546          546
#define GoTo547          547
#define GoTo548          548
#define GoTo549          549
#define GoTo550          550
#define GoTo551          551
#define GoTo552          552
#define GoTo553          553
#define GoTo554          554
#define GoTo555          555
#define GoTo556          556
#define GoTo557          557
#define GoTo558          558
#define GoTo559          559
#define GoTo560          560
#define GoTo561          561
#define GoTo562          562
#define GoTo563          563
#define GoTo564          564
#define GoTo565          565
#define GoTo566          566
#define GoTo567          567
#define GoTo568          568
#define GoTo569          569
#define GoTo570          570
#define GoTo571          571
#define GoTo572          572
#define GoTo573          573
#define GoTo574          574
#define GoTo575          575
#define GoTo576          576
#define GoTo577          577
#define GoTo578          578
#define GoTo579          579
#define GoTo580          580
#define GoTo581          581
#define GoTo582          582
#define GoTo583          583
#define GoTo584          584
#define GoTo585          585
#define GoTo586          586
#define GoTo587          587
#define GoTo588          588
#define GoTo589          589
#define GoTo590          590
#define GoTo591          591
#define GoTo592          592
#define GoTo593          593
#define GoTo594          594
#define GoTo595          595
#define GoTo596          596
#define GoTo597          597
#define GoTo598          598
#define GoTo599          599
#define GoTo600          600
#define GoTo601          601
#define GoTo602          602
#define GoTo603          603
#define GoTo604          604
#define GoTo605          605
#define GoTo606          606
#define GoTo607          607
#define GoTo608          608
#define GoTo609          609
#define GoTo610          610
#define GoTo611          611
#define GoTo612          612
#define GoTo613          613
#define GoTo614          614
#define GoTo615          615
#define GoTo616          616
#define GoTo617          617
#define GoTo618          618
#define GoTo619          619
#define GoTo620          620
#define GoTo621          621
#define GoTo622          622
#define GoTo623          623
#define GoTo624          624
#define GoTo625          625
#define GoTo626          626
#define GoTo627          627
#define GoTo628          628
#define GoTo629          629
#define GoTo630          630
#define GoTo631          631
#define GoTo632          632
#define GoTo633          633
#define GoTo634          634
#define GoTo635          635
#define GoTo636          636
#define GoTo637          637
#define GoTo638          638
#define GoTo639          639
#define GoTo640          640
#define GoTo641          641
#define GoTo642          642
#define GoTo643          643
#define GoTo644          644
#define GoTo645          645
#define GoTo646          646
#define GoTo647          647
#define GoTo648          648
#define GoTo649          649
#define GoTo650          650
#define GoTo651          651
#define GoTo652          652
#define GoTo653          653
#define GoTo654          654
#define GoTo655          655
#define GoTo656          656
#define GoTo657          657
#define GoTo658          658
#define GoTo659          659
#define GoTo660          660
#define GoTo661          661
#define GoTo662          662
#define GoTo663          663
#define GoTo664          664
#define GoTo665          665
#define GoTo666          666
#define GoTo667          667
#define GoTo668          668
#define GoTo669          669
#define GoTo670          670
#define GoTo671          671
#define GoTo672          672
#define GoTo673          673
#define GoTo674          674
#define GoTo675          675
#define GoTo676          676
#define GoTo677          677
#define GoTo678          678
#define GoTo679          679
#define GoTo680          680
#define GoTo681          681
#define GoTo682          682
#define GoTo683          683
#define GoTo684          684
#define GoTo685          685
#define GoTo686          686
#define GoTo687          687
#define GoTo688          688
#define GoTo689          689
#define GoTo690          690
#define GoTo691          691
#define GoTo692          692
#define GoTo693          693
#define GoTo694          694
#define GoTo695          695
#define GoTo696          696
#define GoTo697          697
#define GoTo698          698
#define GoTo699          699
#define GoTo700          700
#define GoTo701          701
#define GoTo702          702
#define GoTo703          703
#define GoTo704          704
#define GoTo705          705
#define GoTo706          706
#define GoTo707          707
#define GoTo708          708
#define GoTo709          709
#define GoTo710          710
#define GoTo711          711
#define GoTo712          712
#define GoTo713          713
#define GoTo714          714
#define GoTo715          715
#define GoTo716          716
#define GoTo717          717
#define GoTo718          718
#define GoTo719          719
#define GoTo720          720
#define GoTo721          721
#define GoTo722          722
#define GoTo723          723
#define GoTo724          724
#define GoTo725          725
#define GoTo726          726
#define GoTo727          727
#define GoTo728          728
#define GoTo729          729
#define GoTo730          730
#define GoTo731          731
#define GoTo732          732
#define GoTo733          733
#define GoTo734          734
#define GoTo735          735
#define GoTo736          736
#define GoTo737          737
#define GoTo738          738
#define GoTo739          739
#define GoTo740          740
#define GoTo741          741
#define GoTo742          742
#define GoTo743          743
#define GoTo744          744
#define GoTo745          745
#define GoTo746          746
#define GoTo747          747
#define GoTo748          748
#define GoTo749          749
#define GoTo750          750
#define GoTo751          751
#define GoTo752          752
#define GoTo753          753
#define GoTo754          754
#define GoTo755          755
#define GoTo756          756
#define GoTo757          757
#define GoTo758          758
#define GoTo759          759
#define GoTo760          760
#define GoTo761          761
#define GoTo762          762
#define GoTo763          763
#define GoTo764          764
#define GoTo765          765
#define GoTo766          766
#define GoTo767          767
#define GoTo768          768
#define GoTo769          769
#define GoTo770          770
#define GoTo771          771
#define GoTo772          772
#define GoTo773          773
#define GoTo774          774
#define GoTo775          775
#define GoTo776          776
#define GoTo777          777
#define GoTo778          778
#define GoTo779          779
#define GoTo780          780
#define GoTo781          781
#define GoTo782          782
#define GoTo783          783
#define GoTo784          784
#define GoTo785          785
#define GoTo786          786
#define GoTo787          787
#define GoTo788          788
#define GoTo789          789
#define GoTo790          790
#define GoTo791          791
#define GoTo792          792
#define GoTo793          793
#define GoTo794          794
#define GoTo795          795
#define GoTo796          796
#define GoTo797          797
#define GoTo798          798
#define GoTo799          799
#define GoTo800          800
#define GoTo801          801
#define GoTo802          802
#define GoTo803          803
#define GoTo804          804
#define GoTo805          805
#define GoTo806          806
#define GoTo807          807
#define GoTo808          808
#define GoTo809          809
#define GoTo810          810
#define GoTo811          811
#define GoTo812          812
#define GoTo813          813
#define GoTo814          814
#define GoTo815          815
#define GoTo816          816
#define GoTo817          817
#define GoTo818          818
#define GoTo819          819
#define GoTo820          820
#define GoTo821          821
#define GoTo822          822
#define GoTo823          823
#define GoTo824          824
#define GoTo825          825
#define GoTo826          826
#define GoTo827          827
#define GoTo828          828
#define GoTo829          829
#define GoTo830          830
#define GoTo831          831
#define GoTo832          832
#define GoTo833          833
#define GoTo834          834
#define GoTo835          835
#define GoTo836          836
#define GoTo837          837
#define GoTo838          838
#define GoTo839          839
#define GoTo840          840
#define GoTo841          841
#define GoTo842          842
#define GoTo843          843
#define GoTo844          844
#define GoTo845          845
#define GoTo846          846
#define GoTo847          847
#define GoTo848          848
#define GoTo849          849
#define GoTo850          850
#define GoTo851          851
#define GoTo852          852
#define GoTo853          853
#define GoTo854          854
#define GoTo855          855
#define GoTo856          856
#define GoTo857          857
#define GoTo858          858
#define GoTo859          859
#define GoTo860          860
#define GoTo861          861
#define GoTo862          862
#define GoTo863          863
#define GoTo864          864
#define GoTo865          865
#define GoTo866          866
#define GoTo867          867
#define GoTo868          868
#define GoTo869          869
#define GoTo870          870
#define GoTo871          871
#define GoTo872          872
#define GoTo873          873
#define GoTo874          874
#define GoTo875          875
#define GoTo876          876
#define GoTo877          877
#define GoTo878          878
#define GoTo879          879
#define GoTo880          880
#define GoTo881          881
#define GoTo882          882
#define GoTo883          883
#define GoTo884          884
#define GoTo885          885
#define GoTo886          886
#define GoTo887          887
#define GoTo888          888
#define GoTo889          889
#define GoTo890          890
#define GoTo891          891
#define GoTo892          892
#define GoTo893          893
#define GoTo894          894
#define GoTo895          895
#define GoTo896          896
#define GoTo897          897
#define GoTo898          898
#define GoTo899          899
#define GoTo900          900
#define GoTo901          901
#define GoTo902          902
#define GoTo903          903
#define GoTo904          904
#define GoTo905          905
#define GoTo906          906
#define GoTo907          907
#define GoTo908          908
#define GoTo909          909
#define GoTo910          910
#define GoTo911          911
#define GoTo912          912
#define GoTo913          913
#define GoTo914          914
#define GoTo915          915
#define GoTo916          916
#define GoTo917          917
#define GoTo918          918
#define GoTo919          919
#define GoTo920          920
#define GoTo921          921
#define GoTo922          922
#define GoTo923          923
#define GoTo924          924
#define GoTo925          925
#define GoTo926          926
#define GoTo927          927
#define GoTo928          928
#define GoTo929          929
#define GoTo930          930
#define GoTo931          931
#define GoTo932          932
#define GoTo933          933
#define GoTo934          934
#define GoTo935          935
#define GoTo936          936
#define GoTo937          937
#define GoTo938          938
#define GoTo939          939
#define GoTo940          940
#define GoTo941          941
#define GoTo942          942
#define GoTo943          943
#define GoTo944          944
#define GoTo945          945
#define GoTo946          946
#define GoTo947          947
#define GoTo948          948
#define GoTo949          949
#define GoTo950          950
#define GoTo951          951
#define GoTo952          952
#define GoTo953          953
#define GoTo954          954
#define GoTo955          955
#define GoTo956          956
#define GoTo957          957
#define GoTo958          958
#define GoTo959          959
#define GoTo960          960
#define GoTo961          961
#define GoTo962          962
#define GoTo963          963
#define GoTo964          964
#define GoTo965          965
#define GoTo966          966
#define GoTo967          967
#define GoTo968          968
#define GoTo969          969
#define GoTo970          970
#define GoTo971          971
#define GoTo972          972
#define GoTo973          973
#define GoTo974          974
#define GoTo975          975
#define GoTo976          976
#define GoTo977          977
#define GoTo978          978
#define GoTo979          979
#define GoTo980          980
#define GoTo981          981
#define GoTo982          982
#define GoTo983          983
#define GoTo984          984
#define GoTo985          985
#define GoTo986          986
#define GoTo987          987
#define GoTo988          988
#define GoTo989          989
#define GoTo990          990
#define GoTo991          991
#define GoTo992          992
#define GoTo993          993
#define GoTo994          994
#define GoTo995          995
#define GoTo996          996
#define GoTo997          997
#define GoTo998          998
#define GoTo999          999


struct syntax_table { /* Table of syntax rules       */
   int tokentype;     /* token type flag             */
   int nextrule;      /* next syntax rule to process */
   char *keyword;     /* optional keyword string     */
   int (*userexit)(char token[], int tokenlen, char msg[101]); /* optional user exit */
};

extern int syntaxchk(char cmdline[],                  /* String to be checked     */
                     struct syntax_table *syntaxtab,  /* Table of syntax rules    */
                     int *tokenloc,                   /* Index value of bad token */
                     int *tokenlen,                   /* Length of bad token      */
                     int *syntxloc);                  /* Index of bad rule        */

